Documentation
¶
Overview ¶
Package detect provides utilities to detect if the local system is a router, or if some remote peer is one.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func IsDeviceRouter ¶
IsDeviceRouter tries to detect whether the local device is a router for other peers. Currently it does this by assuming that it is a router if and only if nobody else is. TODO: try to check local networking config for signs of routing configuration
func IsPeerRouter ¶
IsPeerRouter considers a router to be a peer that has a global unicast allowed IP with a CIDR mask less than the full IP
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.